import { EndpointsInputConfig, EndpointsResolvedConfig, RegionInputConfig, RegionResolvedConfig } from "@trivikr-test/config-resolver";
import { HostHeaderInputConfig, HostHeaderResolvedConfig } from "@trivikr-test/middleware-host-header";
import { RetryInputConfig, RetryResolvedConfig } from "@trivikr-test/middleware-retry";
import { AwsAuthInputConfig, AwsAuthResolvedConfig } from "@trivikr-test/middleware-signing";
import { UserAgentInputConfig, UserAgentResolvedConfig } from "@trivikr-test/middleware-user-agent";
import { HttpHandler as __HttpHandler } from "@trivikr-test/protocol-http";
import { Client as __Client, DefaultsMode, SmithyConfiguration as __SmithyConfiguration, SmithyResolvedConfiguration as __SmithyResolvedConfiguration } from "@trivikr-test/smithy-client";
import { BodyLengthCalculator as __BodyLengthCalculator, Credentials as __Credentials, Decoder as __Decoder, Encoder as __Encoder, HashConstructor as __HashConstructor, HttpHandlerOptions as __HttpHandlerOptions, Logger as __Logger, Provider as __Provider, Provider, RegionInfoProvider, StreamCollector as __StreamCollector, UrlParser as __UrlParser, UserAgent as __UserAgent } from "@trivikr-test/types";
import { DescribeReportCreationCommandInput, DescribeReportCreationCommandOutput } from "./commands/DescribeReportCreationCommand";
import { GetComplianceSummaryCommandInput, GetComplianceSummaryCommandOutput } from "./commands/GetComplianceSummaryCommand";
import { GetResourcesCommandInput, GetResourcesCommandOutput } from "./commands/GetResourcesCommand";
import { GetTagKeysCommandInput, GetTagKeysCommandOutput } from "./commands/GetTagKeysCommand";
import { GetTagValuesCommandInput, GetTagValuesCommandOutput } from "./commands/GetTagValuesCommand";
import { StartReportCreationCommandInput, StartReportCreationCommandOutput } from "./commands/StartReportCreationCommand";
import { TagResourcesCommandInput, TagResourcesCommandOutput } from "./commands/TagResourcesCommand";
import { UntagResourcesCommandInput, UntagResourcesCommandOutput } from "./commands/UntagResourcesCommand";
export declare type ServiceInputTypes = DescribeReportCreationCommandInput | GetComplianceSummaryCommandInput | GetResourcesCommandInput | GetTagKeysCommandInput | GetTagValuesCommandInput | StartReportCreationCommandInput | TagResourcesCommandInput | UntagResourcesCommandInput;
export declare type ServiceOutputTypes = DescribeReportCreationCommandOutput | GetComplianceSummaryCommandOutput | GetResourcesCommandOutput | GetTagKeysCommandOutput | GetTagValuesCommandOutput | StartReportCreationCommandOutput | TagResourcesCommandOutput | UntagResourcesCommandOutput;
export interface ClientDefaults extends Partial<__SmithyResolvedConfiguration<__HttpHandlerOptions>> {
    /**
     * The HTTP handler to use. Fetch in browser and Https in Nodejs.
     */
    requestHandler?: __HttpHandler;
    /**
     * A constructor for a class implementing the {@link __Hash} interface
     * that computes the SHA-256 HMAC or checksum of a string or binary buffer.
     * @internal
     */
    sha256?: __HashConstructor;
    /**
     * The function that will be used to convert strings into HTTP endpoints.
     * @internal
     */
    urlParser?: __UrlParser;
    /**
     * A function that can calculate the length of a request body.
     * @internal
     */
    bodyLengthChecker?: __BodyLengthCalculator;
    /**
     * A function that converts a stream into an array of bytes.
     * @internal
     */
    streamCollector?: __StreamCollector;
    /**
     * The function that will be used to convert a base64-encoded string to a byte array.
     * @internal
     */
    base64Decoder?: __Decoder;
    /**
     * The function that will be used to convert binary data to a base64-encoded string.
     * @internal
     */
    base64Encoder?: __Encoder;
    /**
     * The function that will be used to convert a UTF8-encoded string to a byte array.
     * @internal
     */
    utf8Decoder?: __Decoder;
    /**
     * The function that will be used to convert binary data to a UTF-8 encoded string.
     * @internal
     */
    utf8Encoder?: __Encoder;
    /**
     * The runtime environment.
     * @internal
     */
    runtime?: string;
    /**
     * Disable dyanamically changing the endpoint of the client based on the hostPrefix
     * trait of an operation.
     */
    disableHostPrefix?: boolean;
    /**
     * Value for how many times a request will be made at most in case of retry.
     */
    maxAttempts?: number | __Provider<number>;
    /**
     * Specifies which retry algorithm to use.
     */
    retryMode?: string | __Provider<string>;
    /**
     * Optional logger for logging debug/info/warn/error.
     */
    logger?: __Logger;
    /**
     * Enables IPv6/IPv4 dualstack endpoint.
     */
    useDualstackEndpoint?: boolean | __Provider<boolean>;
    /**
     * Enables FIPS compatible endpoints.
     */
    useFipsEndpoint?: boolean | __Provider<boolean>;
    /**
     * Unique service identifier.
     * @internal
     */
    serviceId?: string;
    /**
     * The AWS region to which this client will send requests
     */
    region?: string | __Provider<string>;
    /**
     * Default credentials provider; Not available in browser runtime.
     * @internal
     */
    credentialDefaultProvider?: (input: any) => __Provider<__Credentials>;
    /**
     * Fetch related hostname, signing name or signing region with given region.
     * @internal
     */
    regionInfoProvider?: RegionInfoProvider;
    /**
     * The provider populating default tracking information to be sent with `user-agent`, `x-amz-user-agent` header
     * @internal
     */
    defaultUserAgentProvider?: Provider<__UserAgent>;
    /**
     * The {@link DefaultsMode} that will be used to determine how certain default configuration options are resolved in the SDK.
     */
    defaultsMode?: DefaultsMode | Provider<DefaultsMode>;
}
declare type ResourceGroupsTaggingAPIClientConfigType = Partial<__SmithyConfiguration<__HttpHandlerOptions>> & ClientDefaults & RegionInputConfig & EndpointsInputConfig & RetryInputConfig & HostHeaderInputConfig & AwsAuthInputConfig & UserAgentInputConfig;
/**
 * The configuration interface of ResourceGroupsTaggingAPIClient class constructor that set the region, credentials and other options.
 */
export interface ResourceGroupsTaggingAPIClientConfig extends ResourceGroupsTaggingAPIClientConfigType {
}
declare type ResourceGroupsTaggingAPIClientResolvedConfigType = __SmithyResolvedConfiguration<__HttpHandlerOptions> & Required<ClientDefaults> & RegionResolvedConfig & EndpointsResolvedConfig & RetryResolvedConfig & HostHeaderResolvedConfig & AwsAuthResolvedConfig & UserAgentResolvedConfig;
/**
 * The resolved configuration interface of ResourceGroupsTaggingAPIClient class. This is resolved and normalized from the {@link ResourceGroupsTaggingAPIClientConfig | constructor configuration interface}.
 */
export interface ResourceGroupsTaggingAPIClientResolvedConfig extends ResourceGroupsTaggingAPIClientResolvedConfigType {
}
/**
 * <fullname>Resource Groups Tagging API</fullname>
 */
export declare class ResourceGroupsTaggingAPIClient extends __Client<__HttpHandlerOptions, ServiceInputTypes, ServiceOutputTypes, ResourceGroupsTaggingAPIClientResolvedConfig> {
    /**
     * The resolved configuration of ResourceGroupsTaggingAPIClient class. This is resolved and normalized from the {@link ResourceGroupsTaggingAPIClientConfig | constructor configuration interface}.
     */
    readonly config: ResourceGroupsTaggingAPIClientResolvedConfig;
    constructor(configuration: ResourceGroupsTaggingAPIClientConfig);
    /**
     * Destroy underlying resources, like sockets. It's usually not necessary to do this.
     * However in Node.js, it's best to explicitly shut down the client's agent when it is no longer needed.
     * Otherwise, sockets might stay open for quite a long time before the server terminates them.
     */
    destroy(): void;
}
export {};
