import { Command as $Command } from "@trivikr-test/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@trivikr-test/types";
import { UntagResourcesInput, UntagResourcesOutput } from "../models/models_0";
import { ResourceGroupsTaggingAPIClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ResourceGroupsTaggingAPIClient";
export interface UntagResourcesCommandInput extends UntagResourcesInput {
}
export interface UntagResourcesCommandOutput extends UntagResourcesOutput, __MetadataBearer {
}
/**
 * <p>Removes the specified tags from the specified resources. When you specify a tag key,
 *             the action removes both that key and its associated value. The operation succeeds even
 *             if you attempt to remove tags from a resource that were already removed. Note the
 *             following:</p>
 *         <ul>
 *             <li>
 *                 <p>To remove tags from a resource, you need the necessary permissions for the
 *                     service that the resource belongs to as well as permissions for removing tags.
 *                     For more information, see the documentation for the service whose resource you
 *                     want to untag.</p>
 *             </li>
 *             <li>
 *                 <p>You can only tag resources that are located in the specified Amazon Web Services Region for
 *                     the calling Amazon Web Services account.</p>
 *             </li>
 *          </ul>
 *
 *         <p>
 *             <b>Minimum permissions</b>
 *          </p>
 *         <p>In addition to the <code>tag:UntagResources</code> permission required by this
 *             operation, you must also have the remove tags permission defined by the service that
 *             created the resource. For example, to remove the tags from an Amazon EC2 instance using the
 *                 <code>UntagResources</code> operation, you must have both of the following
 *             permissions:</p>
 *         <ul>
 *             <li>
 *                 <p>
 *                   <code>tag:UntagResource</code>
 *                </p>
 *             </li>
 *             <li>
 *                 <p>
 *                   <code>ec2:DeleteTags</code>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ResourceGroupsTaggingAPIClient, UntagResourcesCommand } from "@trivikr-test/client-resource-groups-tagging-api"; // ES Modules import
 * // const { ResourceGroupsTaggingAPIClient, UntagResourcesCommand } = require("@trivikr-test/client-resource-groups-tagging-api"); // CommonJS import
 * const client = new ResourceGroupsTaggingAPIClient(config);
 * const command = new UntagResourcesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link UntagResourcesCommandInput} for command's `input` shape.
 * @see {@link UntagResourcesCommandOutput} for command's `response` shape.
 * @see {@link ResourceGroupsTaggingAPIClientResolvedConfig | config} for ResourceGroupsTaggingAPIClient's `config` shape.
 *
 */
export declare class UntagResourcesCommand extends $Command<UntagResourcesCommandInput, UntagResourcesCommandOutput, ResourceGroupsTaggingAPIClientResolvedConfig> {
    readonly input: UntagResourcesCommandInput;
    constructor(input: UntagResourcesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ResourceGroupsTaggingAPIClientResolvedConfig, options?: __HttpHandlerOptions): Handler<UntagResourcesCommandInput, UntagResourcesCommandOutput>;
    private serialize;
    private deserialize;
}
