import { ExceptionOptionType as __ExceptionOptionType } from "@trivikr-test/smithy-client";
import { ResourceGroupsTaggingAPIServiceException as __BaseException } from "./ResourceGroupsTaggingAPIServiceException";

export interface ComplianceDetails {
  NoncompliantKeys?: string[];

  KeysWithNoncompliantValues?: string[];

  ComplianceStatus?: boolean;
}

export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  Message?: string;

  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}

export declare class ConstraintViolationException extends __BaseException {
  readonly name: "ConstraintViolationException";
  readonly $fault: "client";
  Message?: string;

  constructor(
    opts: __ExceptionOptionType<ConstraintViolationException, __BaseException>
  );
}
export interface DescribeReportCreationInput {}
export interface DescribeReportCreationOutput {
  Status?: string;

  S3Location?: string;

  StartDate?: string;

  ErrorMessage?: string;
}

export declare class InternalServiceException extends __BaseException {
  readonly name: "InternalServiceException";
  readonly $fault: "server";
  Message?: string;

  constructor(
    opts: __ExceptionOptionType<InternalServiceException, __BaseException>
  );
}

export declare class InvalidParameterException extends __BaseException {
  readonly name: "InvalidParameterException";
  readonly $fault: "client";
  Message?: string;

  constructor(
    opts: __ExceptionOptionType<InvalidParameterException, __BaseException>
  );
}

export declare class ThrottledException extends __BaseException {
  readonly name: "ThrottledException";
  readonly $fault: "client";
  Message?: string;

  constructor(opts: __ExceptionOptionType<ThrottledException, __BaseException>);
}
export declare enum ErrorCode {
  INTERNAL_SERVICE_EXCEPTION = "InternalServiceException",
  INVALID_PARAMETER_EXCEPTION = "InvalidParameterException",
}

export interface FailureInfo {
  StatusCode?: number;

  ErrorCode?: ErrorCode | string;

  ErrorMessage?: string;
}
export declare enum GroupByAttribute {
  REGION = "REGION",
  RESOURCE_TYPE = "RESOURCE_TYPE",
  TARGET_ID = "TARGET_ID",
}
export interface GetComplianceSummaryInput {
  TargetIdFilters?: string[];

  RegionFilters?: string[];

  ResourceTypeFilters?: string[];

  TagKeyFilters?: string[];

  GroupBy?: (GroupByAttribute | string)[];

  MaxResults?: number;

  PaginationToken?: string;
}
export declare enum TargetIdType {
  ACCOUNT = "ACCOUNT",
  OU = "OU",
  ROOT = "ROOT",
}

export interface Summary {
  LastUpdated?: string;

  TargetId?: string;

  TargetIdType?: TargetIdType | string;

  Region?: string;

  ResourceType?: string;

  NonCompliantResources?: number;
}
export interface GetComplianceSummaryOutput {
  SummaryList?: Summary[];

  PaginationToken?: string;
}

export interface TagFilter {
  Key?: string;

  Values?: string[];
}
export interface GetResourcesInput {
  PaginationToken?: string;

  TagFilters?: TagFilter[];

  ResourcesPerPage?: number;

  TagsPerPage?: number;

  ResourceTypeFilters?: string[];

  IncludeComplianceDetails?: boolean;

  ExcludeCompliantResources?: boolean;

  ResourceARNList?: string[];
}

export interface Tag {
  Key: string | undefined;

  Value: string | undefined;
}

export interface ResourceTagMapping {
  ResourceARN?: string;

  Tags?: Tag[];

  ComplianceDetails?: ComplianceDetails;
}
export interface GetResourcesOutput {
  PaginationToken?: string;

  ResourceTagMappingList?: ResourceTagMapping[];
}

export declare class PaginationTokenExpiredException extends __BaseException {
  readonly name: "PaginationTokenExpiredException";
  readonly $fault: "client";
  Message?: string;

  constructor(
    opts: __ExceptionOptionType<
      PaginationTokenExpiredException,
      __BaseException
    >
  );
}
export interface GetTagKeysInput {
  PaginationToken?: string;
}
export interface GetTagKeysOutput {
  PaginationToken?: string;

  TagKeys?: string[];
}
export interface GetTagValuesInput {
  PaginationToken?: string;

  Key: string | undefined;
}
export interface GetTagValuesOutput {
  PaginationToken?: string;

  TagValues?: string[];
}
export interface StartReportCreationInput {
  S3Bucket: string | undefined;
}
export interface StartReportCreationOutput {}
export interface TagResourcesInput {
  ResourceARNList: string[] | undefined;

  Tags: Record<string, string> | undefined;
}
export interface TagResourcesOutput {
  FailedResourcesMap?: Record<string, FailureInfo>;
}
export interface UntagResourcesInput {
  ResourceARNList: string[] | undefined;

  TagKeys: string[] | undefined;
}
export interface UntagResourcesOutput {
  FailedResourcesMap?: Record<string, FailureInfo>;
}

export declare const ComplianceDetailsFilterSensitiveLog: (
  obj: ComplianceDetails
) => any;

export declare const DescribeReportCreationInputFilterSensitiveLog: (
  obj: DescribeReportCreationInput
) => any;

export declare const DescribeReportCreationOutputFilterSensitiveLog: (
  obj: DescribeReportCreationOutput
) => any;

export declare const FailureInfoFilterSensitiveLog: (obj: FailureInfo) => any;

export declare const GetComplianceSummaryInputFilterSensitiveLog: (
  obj: GetComplianceSummaryInput
) => any;

export declare const SummaryFilterSensitiveLog: (obj: Summary) => any;

export declare const GetComplianceSummaryOutputFilterSensitiveLog: (
  obj: GetComplianceSummaryOutput
) => any;

export declare const TagFilterFilterSensitiveLog: (obj: TagFilter) => any;

export declare const GetResourcesInputFilterSensitiveLog: (
  obj: GetResourcesInput
) => any;

export declare const TagFilterSensitiveLog: (obj: Tag) => any;

export declare const ResourceTagMappingFilterSensitiveLog: (
  obj: ResourceTagMapping
) => any;

export declare const GetResourcesOutputFilterSensitiveLog: (
  obj: GetResourcesOutput
) => any;

export declare const GetTagKeysInputFilterSensitiveLog: (
  obj: GetTagKeysInput
) => any;

export declare const GetTagKeysOutputFilterSensitiveLog: (
  obj: GetTagKeysOutput
) => any;

export declare const GetTagValuesInputFilterSensitiveLog: (
  obj: GetTagValuesInput
) => any;

export declare const GetTagValuesOutputFilterSensitiveLog: (
  obj: GetTagValuesOutput
) => any;

export declare const StartReportCreationInputFilterSensitiveLog: (
  obj: StartReportCreationInput
) => any;

export declare const StartReportCreationOutputFilterSensitiveLog: (
  obj: StartReportCreationOutput
) => any;

export declare const TagResourcesInputFilterSensitiveLog: (
  obj: TagResourcesInput
) => any;

export declare const TagResourcesOutputFilterSensitiveLog: (
  obj: TagResourcesOutput
) => any;

export declare const UntagResourcesInputFilterSensitiveLog: (
  obj: UntagResourcesInput
) => any;

export declare const UntagResourcesOutputFilterSensitiveLog: (
  obj: UntagResourcesOutput
) => any;
